@@ -1,7 +1,7 @@
 from typing import Literal
 
 from astropy.io import fits
-from dkist_processing_common.tasks.write_l1 import WriteL1Frame
+from dkist_processing_common.tasks import WriteL1Frame
 
 
 class WriteL1Data(WriteL1Frame):
@@ -11,7 +11,6 @@ class WriteL1Data(WriteL1Frame):
         header["DAAXES"] = 2
         header["DEAXES"] = 1
         header["DNAXIS"] = 3
-        header["FRAMEWAV"] = 123.45
         header["LEVEL"] = 1
         header["WAVEMAX"] = 124
         header["WAVEMIN"] = 123
@@ -33,11 +32,6 @@ class WriteL1Data(WriteL1Frame):
         header["DWNAME1"] = "helioprojective longitude"
         header["DWNAME2"] = "helioprojective latitude"
         header["DWNAME3"] = "time"
-        header["CALVERS"] = ""
-        header["CAL_URL"] = ""
-        header["HEADVERS"] = ""
-        header["HEAD_URL"] = ""
-        header["INFO_URL"] = ""
         header["NBIN"] = 1
         for i in range(1, header["NAXIS"] + 1):
             header[f"NBIN{i}"] = 1
